@@ -1,11 +1,12 @@
-#Helper function to compute postStrat total for bootstrapping
+# Helper function to compute postStrat total for bootstrapping
 
 postStratt <- function(data, xpoptab, indices){
 
-  #Define variables
+  # Define variables
   x= N_h = N_h_hats = ps_h = poptotal_h = strat_pop_total = NULL  
   
-    #data: 3rd column:y, 2nd column:pis, 1st column: xsample
+    # data: 4th column: y_den, 3rd column:y_num, 
+    # 2nd column:pis, 1st column: xsample
   d <- data[indices,]
   
   #y
@@ -20,10 +21,10 @@ postStratt <- function(data, xpoptab, indices){
   #Estimator
   #Compute estimator
   dat <- data.frame(x=xsample, pi=pis,y=y)
-  tab <- dat %>%
-    group_by(x) %>%
-    summarize(poptotal_h = y%*%pi^(-1),N_h_hats = sum(pi^(-1)), var_h = var(y)) %>%
-    inner_join(xpoptab, by=c("x")) %>%
+  tab <- dat |>
+    group_by(x) |>
+    summarize(poptotal_h = y%*%pi^(-1),N_h_hats = sum(pi^(-1)), var_h = var(y)) |>
+    inner_join(xpoptab, by=c("x")) |>
     mutate(ps_h = N_h/N_h_hats, strat_pop_total = ps_h*poptotal_h, strat_pop_mean = strat_pop_total/N_h)
   
   
